package com.example.hpclock;
import java.io.IOException;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.AsyncTask;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ToggleButton;

public class MainActivity extends Activity {
	
	private static final int PREFERENCE_REQUEST = 1;		// REQUEST CODE FOR PREFERENCE ACTIVITY
	private static final String DEBUG_TAG = "HPClock";		// DEBUG TAG FOR LOGCAT
	private static ToggleButton currButton = null;			// BUTTON CURRENTLY SELECTED
	
	/* App preferences to be loaded in */
	private static String userID = null;					// user id
	private static String arduinoIP = null;					// arduino IP
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
    	super.onCreateOptionsMenu(menu);
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item){
    	// Option selected in menu
    	switch(item.getItemId()){
	    	case R.id.menu_settings:
	    		Intent intent = new Intent();
	    		intent.setClass(this, PrefActivity.class);
	    		startActivityForResult(intent, PREFERENCE_REQUEST);
	    		
	    		return true;	    		
	    	case R.id.menu_exit:
	    		finish();
	    		return true;	    
	    	default:
	    		return super.onOptionsItemSelected(item);
    	}
    }
    
    @Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if(resultCode == Activity.RESULT_OK && requestCode == PREFERENCE_REQUEST)
		{
			// RESET VARIABLES BASED ON NEW PREFERENCE SETTINGS
			SharedPreferences mypref = PreferenceManager.getDefaultSharedPreferences(this);
			userID = mypref.getString("userID_preference", null);
			arduinoIP = mypref.getString("arduinoIP_preference", null);
		}
		
	}

	/** called when user clicks send 
     * @throws Exception */
    public void SendHTTP(View view) throws Exception {
    	AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(this);
    	alertDialogBuilder
		.setCancelable(false)
		.setPositiveButton("OK",new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog,int id) {    				
				dialog.cancel();
			}
		});
    	AlertDialog alertDialog;
    	
    	// check if network connection available    	    
    	ConnectivityManager connMgr = (ConnectivityManager)getSystemService(Context.CONNECTIVITY_SERVICE);
    	NetworkInfo networkInfo = connMgr.getActiveNetworkInfo();

    	
		if(networkInfo != null && networkInfo.isConnected())
    	{
    		// Connection available
			// mark button as checked and decheck previous button
			if(currButton!=null)
			{
				currButton.setChecked(false);
			}
			currButton = (ToggleButton)view;
			currButton.setChecked(true);
			ArduinoTask postArduino = new ArduinoTask();
    		
    		String ButtonID = null;
    		switch(currButton.getId())
    		{
	    		case R.id.Button_1:
	    			ButtonID = "1";
	    			break;
	    		case R.id.Button_2:
	    			ButtonID = "2";
	    			break;
	    		case R.id.Button_3:
	    			ButtonID = "3";
	    			break;
	    		case R.id.Button_4:
	    			ButtonID = "4";
	    			break;
	    		case R.id.Button_5:
	    			ButtonID = "5";
	    			break;
	    		case R.id.Button_6:
	    			ButtonID = "6";
	    			break;
	    		case R.id.Button_7:
	    			ButtonID = "7";
	    			break;
	    		case R.id.Button_8:
	    			ButtonID = "8";
	    			break;
	    		case R.id.Button_9:
	    			ButtonID = "9";
	    			break;
	    		case R.id.Button_10:
	    			ButtonID = "10";
	    			break;
	    		case R.id.Button_11:
	    			ButtonID = "11";
	    			break;
	    		case R.id.Button_12:
	    			ButtonID = "12";
	    			break;
	    		default:
	    			throw new Exception("View ID not a valid button press");
    		}
    		
    		// Start the async task to connect with the arduino
    		postArduino.execute("http://192.168.1.74", ButtonID);	
    		
    		// if bad result, display error message
    		switch(postArduino.get()){
	    		case -1:
	    			alertDialogBuilder.setTitle("Unable to communicate with Arduino.  Check IP address.");
					// create alert dialog
					alertDialog = alertDialogBuilder.create();
					alertDialog.show();
	    			break;
    			case 0:
    				alertDialogBuilder.setTitle("Unsuccessful post to arduino. Check arduino server.");
    				// create alert dialog
    				alertDialog = alertDialogBuilder.create();
    				alertDialog.show();
    				break;
    		}
    		
    	} else
    	{    		
        	
    		// set title
    		alertDialogBuilder.setTitle("No WIFI available.");


			// create alert dialog
			alertDialog = alertDialogBuilder.create();
			alertDialog.show();
    	}	
    }
    
    private class ArduinoTask extends AsyncTask<String, Object, Integer> {

		@Override
        protected Integer doInBackground(String... urls) {
        	try {
        		URL url = new URL(urls[0]);
				HttpURLConnection conn = (HttpURLConnection) url.openConnection();
				conn.setReadTimeout(10000 /* milliseconds */);
				conn.setConnectTimeout(15000 /* milliseconds */);
				conn.setRequestMethod("POST");
				conn.setDoInput(true);
				conn.setRequestProperty("Content-Type", "application/json");
				conn.setRequestProperty("Accept", "application/json");
	            
	            // Starts the query
	            conn.connect();

	            // construct JSON object and write it to server
	            byte[] outputBytes = ("{\"id\":"+urls[1]+"}").getBytes("UTF-8");
	            OutputStream os = conn.getOutputStream();
	            os.write(outputBytes);
	            os.close();
				 
	            if(conn.getResponseCode()!=200) {
	            	// Unsuccessful post
	            	return 0;
	            }
	            return 1; // successful post
            } catch (IOException e) {
                return -1;
            }
        }

    }
    

}
